vscode-cudacpp installs statistics
By kriegalex · VS Code Marketplace · Programming Languages
CUDA C++ language support for Visual Studio Code
vscode-cudacpp has 251,996 recorded installs on VS Code Marketplace.
It ranks #1300 of 2,500 tracked VS Code Marketplace listings by installs.
It is rated 1.4 out of 5 from 9 ratings.
PluginStats has 3 daily observations since Oct 16, 2026; the latest is from Oct 18, 2026.
Rating: 1.44 / 5 from 9 ratings
About vscode-cudacpp
CUDA for VSCode (syntax + snippets)
This extension aims at providing syntax support and snippets for CUDA (C++) in VS Code.
Features
Code coloring
This extension supports most of the basic CUDA keywords and functions, such as but not limited to :
• cudaMalloc, cudaFree, ... • \_\_global\_\_, \_\_device\_\_, \_\_host\_\_, ... • atomicAdd, atomicSub, surfCubemapLayeredread, ... • \_\_shfl_down, \_\_syncthreads, ...
To maximize compatibility with existing popular themes, textmate language grammar guidelines have not always been respected (external libraries like CUDA in support scope). If your theme still doesn't color the CUDA code, you can set them with the template rules below (put this into your VSCode user settings in settings.json). This can also be used to override your theme colors, if you want to separate C++ and CUDA colors.
List of scopes
• "support.function.cuda-cpp" : atomicAdd, cudaMalloc, cudaFree, ... • "keyword.function.qualifier.cuda-cpp" : \_\_global\_\_, \_\_host\_\_, \_\_device\_\_, ... • "storage.modifier.cuda-cpp" : \_\_constant\_\_, \_\_device\_\_, \_\_shared\_\_, ... • "support.type.cuda-cpp" : dim3, uint1, ulong1, ... • "variable.language.cuda-cpp" : gridDim, blockIdx, blockDim, threadIdx, warpSize • "punctuation.section.kernel" : the kernel brackets >> • "meta.kernel-call.cuda-cpp entity.name.function.c" : the function name before the >>
CUDA snippets
The following snippets are available :
• \_\_s : __syncthreads(); • cmal : cudaMalloc((void**)&${1:variable}, ${2:bytes}); • cmalmng : cudaMallocManaged((void**)&${1:variable}, ${2:bytes}); • cmem : cudaMemcpy(${1:dest}, ${2:src}, ${3:bytes}, cudaMemcpy${4:Host}To${5:Device}); • cfree : cudaFree(${1:variable}); • kerneldef : \_\_global\_\_ void ${1:kernel}(${2}) {\n} • kernelcall : ${1:kernel}>>(${4}); • thrusthv : thrust::host_vector v$0; • thrustdv : thrust::device_vector v$0;
Requirements
• VSCode 1.18+. Slightly older versions should work, very old versions are not guaranteed to work. • This extension has been tested with the default VSCode skin (dark+) and the popular One Dark Pro theme.
Extension Settings
This extension contributes the following settings:
• none
Known Issues
• No support for Intellisense navigation through code (right click->Go to definition,...). This will be implemented by another extension dedicated to IntelliSense and debugging.
Planned features
Below are listed the features that ideally should be available for this extension. IntelliSense and debugging coexist in another repository. There is no guarantees this features will be implemented.
• Icon for files • CUDA syntax colors as parameters of this extension instead of using "editor.tokenColorCustomizations" in settings.json
Feature requests & issues
Requests should be made here : https://github.com/kriegalex/vscode-cuda/issues
Release Notes
See also the changelog
0.1.0
Initial release of vscode-cuda extension
0.1.1
Better documentation
Description from the VS Code Marketplace listing.
- c++
- cuda
- CUDA C++
- snippet
Where vscode-cudacpp sits in the listing
Each band is one page of 20. Installs on a log scale. Placement is projected from installs, so it can differ from the marketplace's own sort order. Hover a dot to see the listing.
Charts
Images: 30d · 1y · all time · 1600×900 dark
Adoption over time
7/30/90-day growth
Ranking history
Filled points are observed values; hollow points come from Internet Archive snapshots of the listing page. Dashed segments span periods with no observations — values between points are not interpolated.
Recent observations
Full history (3)Similar VS Code Marketplace Programming Languages plugins
Data source
Install counts, average rating, and rating counts come from the public Visual Studio Marketplace gallery API. Installs are cumulative and exclude updates.
Listing: https://marketplace.visualstudio.com/items?itemName=kriegalex.vscode-cudacpp. First seen Oct 16, 2026; last successful collection Oct 18, 2026. See the methodology.